@@ -23,7 +23,7 @@ import sys
 distname = 'nazca'
 modname = 'nazca'
 
-numversion = (0, 6, 1)
+numversion = (0, 7, 0)
 version = '.'.join([str(num) for num in numversion])
 
 license = 'LGPL' # 2.1 or later
@@ -32,6 +32,10 @@ web = "https://www.logilab.org/project/nazca"
 author = "Logilab"
 author_email = "contact@logilab.fr"
 
+__depends__ = {
+    'scipy': None,
+    'scikit-learn': None,
+}
 
 from os.path import join
 include_dirs = [join('test', 'data'), 'data', 'examples', 'ner', 'rl', 'utils']
