@@ -26,7 +26,7 @@ from nazca.ner.sources import (NerSourceLexicon,
                                           NerSourceSparql,
                                           NerSourceRql)
 from nazca.ner import NerProcess
-from nazca.utils.tokenizer import Token, Sentence
+from nazca.utils.tokenizer import Token, Sentence, NLTK_AVAILABLE
 from nazca.ner.preprocessors import NerStopwordsFilterPreprocessor
 
 
@@ -57,15 +57,18 @@ class NerTest(unittest.TestCase):
     def test_sparql_source(self):
         """ Test sparql source """
         source = NerSourceSparql(u'http://dbpedia.org/sparql',
-                                 u'''SELECT DISTINCT ?uri
-                                     WHERE{
-                                     ?uri rdfs:label "%(word)s"@en .
-                                     ?uri rdf:type ?type}''')
+                             u'''SELECT DISTINCT ?uri
+                                 WHERE {
+                                 ?uri rdf:type <http://dbpedia.org/ontology/ProgrammingLanguage> ;
+                                      dbpedia-owl:designer <http://dbpedia.org/resource/Guido_van_Rossum> ;
+                                      rdfs:label ?label.
+                                 FILTER(regex(?label, "^%(word)s"))
+                                 }''')
         self.assertEqual(source.query_word('Python'),
-                         [u'http://dbpedia.org/resource/Python',
-                          u'http://sw.opencyc.org/2008/06/10/concept/en/Python_ProgrammingLanguage',
-                          u'http://sw.opencyc.org/2008/06/10/concept/Mx4r74UIARqkEdac2QACs0uFOQ'])
+                         ['http://dbpedia.org/resource/Python_(programming_language)',
+                          'http://dbpedia.org/resource/Python_for_S60'])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process(self):
         """ Test ner process """
         text = 'Hello everyone, this is   me speaking. And me.'
@@ -82,8 +85,9 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46)))])
+                                           sentence=Sentence(indice=1, start=39, end=46)))])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process_multisources(self):
         """ Test ner process """
         text = 'Hello everyone, this is   me speaking. And me.'
@@ -105,10 +109,10 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46))),
+                                           sentence=Sentence(indice=1, start=39, end=46))),
                           ('http://example2.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46)))])
+                                           sentence=Sentence(indice=1, start=39, end=46)))])
         # Two sources, unique
         ner = NerProcess((source1, source2), unique=True)
         named_entities = ner.process_text(text)
@@ -121,7 +125,7 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46)))])
+                                           sentence=Sentence(indice=1, start=39, end=46)))])
         # Two sources inversed, unique
         ner = NerProcess((source2, source1), unique=True)
         named_entities = ner.process_text(text)
@@ -134,8 +138,9 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example2.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46)))])
+                                           sentence=Sentence(indice=1, start=39, end=46)))])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process_add_sources(self):
         """ Test ner process """
         text = 'Hello everyone, this is   me speaking. And me.'
@@ -153,7 +158,7 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46))),])
+                                           sentence=Sentence(indice=1, start=39, end=46))),])
         # Two sources, not unique
         ner.add_ner_source(source2)
         named_entities = ner.process_text(text)
@@ -169,11 +174,12 @@ class NerTest(unittest.TestCase):
                                            sentence=Sentence(indice=0, start=0, end=38))),
                           ('http://example.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46))),
+                                           sentence=Sentence(indice=1, start=39, end=46))),
                           ('http://example2.com/me', None,
                            Token(word='me', start=43, end=45,
-                                           sentence=Sentence(indice=1, start=38, end=46)))])
+                                           sentence=Sentence(indice=1, start=39, end=46)))])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process_preprocess(self):
         """ Test ner process """
         text = 'Hello Toto, this is   me speaking. And me.'
@@ -187,6 +193,7 @@ class NerTest(unittest.TestCase):
                                            Token(word='Toto', start=6, end=10,
                                                  sentence=Sentence(indice=0, start=0, end=34)))])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process_add_preprocess(self):
         """ Test ner process """
         text = 'Hello Toto, this is   me speaking. And me.'
@@ -204,13 +211,14 @@ class NerTest(unittest.TestCase):
                                  sentence=Sentence(indice=0, start=0, end=34))),
                           ('http://example.com/me', None,
                            Token(word='me', start=39, end=41,
-                                 sentence=Sentence(indice=1, start=34, end=42)))])
+                                 sentence=Sentence(indice=1, start=35, end=42)))])
         ner.add_preprocessors(preprocessor)
         named_entities = ner.process_text(text)
         self.assertEqual(named_entities, [('http://example.com/toto', None,
                                            Token(word='Toto', start=6, end=10,
                                                  sentence=Sentence(indice=0, start=0, end=34)))])
 
+    @unittest.skipUnless(NLTK_AVAILABLE, 'nltk is not available')
     def test_ner_process_chained_word(self):
         """ Test ner process """
         text = 'Hello everyone me, this is   me speaking. And me.'
@@ -227,7 +235,8 @@ class NerTest(unittest.TestCase):
                            Token(word='me', start=29, end=31,
                                  sentence=Sentence(indice=0, start=0, end=41))),
                           ('http://example.com/me', None,
-                           Token(word='me', start=46, end=48, sentence=Sentence(indice=1, start=41, end=49)))])
+                           Token(word='me', start=46, end=48,
+                                 sentence=Sentence(indice=1, start=42, end=49)))])
 
 
 if __name__ == '__main__':
